==> src-foundations-0.16.1.tgz: package/typography/obj/index.js <==
// The theme file is based on the specification at https://system-ui.com/theme
//
// WARNING!
//
// This is an internal file to be consumed by the src-foundations package only
//
// It contains the lowest level primitives for the entire design system.
// Be very, *very* careful when changing the values in here, changes are likely
// to have a wide-ranging impact across all applications
//
// DANGEROUS CHANGES
//
// The following will almost certainly require further changes to src-foundations.
// They will likely also impact every application that consumes src-foundations
//
// - Updating a value
// - Removing a value
// - Inserting a value into an array
//
// SAFE CHANGES
//
// - Pushing a value onto the end of an array
// - Exporting a new object or array
var fontSizes = [12, 15, 17, 20, 24, 28, 34, 42, 50, 70];
var fonts = {
  titlepiece: "GT Guardian Titlepiece, Georgia, serif",
  headlineSerif: "GH Guardian Headline, Guardian Egyptian Web, Georgia, serif",
  bodySerif: "GuardianTextEgyptian, Guardian Text Egyptian Web, Georgia, serif",
  bodySans: "GuardianTextSans, Guardian Text Sans Web, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif"
};
var lineHeights = [1.15, 1.35, 1.5];
var fontWeights = [300, 400, 500, 700]; // Arrays of colours should have pillar colors first

var titlepieceSizes = {
  small: fontSizes[7],
  //42px
  medium: fontSizes[8],
  //50px
  large: fontSizes[9] //70px

};
var headlineSizes = {
  xxxsmall: fontSizes[2],
  //17px
  xxsmall: fontSizes[3],
  //20px
  xsmall: fontSizes[4],
  //24px
  small: fontSizes[5],
  //28px
  medium: fontSizes[6],
  //34px
  large: fontSizes[7],
  //42px
  xlarge: fontSizes[8] //50px

};
var bodySizes = {
  small: fontSizes[1],
  //15px
  medium: fontSizes[2] //17px

};
var textSansSizes = {
  xsmall: fontSizes[0],
  //12px
  small: fontSizes[1],
  //15px
  medium: fontSizes[2],
  //17px
  large: fontSizes[3],
  //20px
  xlarge: fontSizes[4] //24px

};
var fontSizeMapping = {
  titlepiece: titlepieceSizes,
  headline: headlineSizes,
  body: bodySizes,
  textSans: textSansSizes
};
var remFontSizes = fontSizes.map(function (fontSize) {
  return fontSize / 16;
});
var remTitlepieceSizes = {
  small: remFontSizes[7],
  //42px
  medium: remFontSizes[8],
  //50px
  large: remFontSizes[9] //70px

};
var remHeadlineSizes = {
  xxxsmall: remFontSizes[2],
  //17px
  xxsmall: remFontSizes[3],
  //20px
  xsmall: remFontSizes[4],
  //24px
  small: remFontSizes[5],
  //28px
  medium: remFontSizes[6],
  //34px
  large: remFontSizes[7],
  //42px
  xlarge: remFontSizes[8] //50px

};
var remBodySizes = {
  small: remFontSizes[1],
  //15px
  medium: remFontSizes[2] //17px

};
var remTextSansSizes = {
  xsmall: remFontSizes[0],
  //12px
  small: remFontSizes[1],
  //15px
  medium: remFontSizes[2],
  //17px
  large: remFontSizes[3],
  //20px
  xlarge: remFontSizes[4] //24px

};
var fontMapping = {
  titlepiece: fonts.titlepiece,
  headline: fonts.headlineSerif,
  body: fonts.bodySerif,
  textSans: fonts.bodySans
};
var lineHeightMapping = {
  tight: lineHeights[0],
  regular: lineHeights[1],
  loose: lineHeights[2]
};
var fontWeightMapping = {
  light: fontWeights[0],
  regular: fontWeights[1],
  medium: fontWeights[2],
  bold: fontWeights[3]
};
var availableFonts = {
  titlepiece: {
    bold: {
      hasItalic: false
    }
  },
  headline: {
    light: {
      hasItalic: true
    },
    medium: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  },
  body: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: true
    }
  },
  textSans: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  }
};
Object.freeze(titlepieceSizes);
Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);
Object.freeze(remTitlepieceSizes);
Object.freeze(remHeadlineSizes);
Object.freeze(remBodySizes);
Object.freeze(remTextSansSizes);
Object.freeze(fontMapping);
Object.freeze(fontSizeMapping);
Object.freeze(fontWeightMapping);
Object.freeze(lineHeightMapping);
Object.freeze(availableFonts);

var fs = function fs(category) {
  return function (level, _ref) {
    var lineHeight = _ref.lineHeight,
        fontWeight = _ref.fontWeight,
        italic = _ref.italic,
        unit = _ref.unit;
    var fontFamilyValue = fontMapping[category];
    var fontSizeValue = unit === "px" ? fontSizeMapping[category][level] : "".concat(fontSizeMapping[category][level] / 16, "rem");
    var lineHeightValue = unit === "px" ? "".concat(lineHeightMapping[lineHeight] * fontSizeMapping[category][level], "px") : lineHeightMapping[lineHeight]; // TODO: consider logging an error in development if a requested
    // font is unavailable

    var requestedFont = availableFonts[category][fontWeight];
    var fontWeightValue = requestedFont ? fontWeightMapping[fontWeight] : "";
    var fontStyleValue = italic && requestedFont && requestedFont.hasItalic ? "italic" : "";
    return Object.assign({
      fontFamily: fontFamilyValue,
      fontSize: fontSizeValue,
      lineHeight: lineHeightValue
    }, fontWeightValue ? {
      fontWeight: fontWeightValue
    } : {}, fontStyleValue ? {
      fontStyle: fontStyleValue
    } : {});
  };
};

var titlepieceDefaults = {
  lineHeight: "tight",
  fontWeight: "bold",
  italic: false,
  unit: "rem"
};
var titlepieceFs = fs("titlepiece");
var titlepiece = {
  small: function small(options) {
    return titlepieceFs("small", Object.assign({}, titlepieceDefaults, options));
  },
  medium: function medium(options) {
    return titlepieceFs("medium", Object.assign({}, titlepieceDefaults, options));
  },
  large: function large(options) {
    return titlepieceFs("large", Object.assign({}, titlepieceDefaults, options));
  }
};
var headlineDefaults = {
  lineHeight: "tight",
  fontWeight: "medium",
  italic: false,
  unit: "rem"
};
var headlineFs = fs("headline");
var headline = {
  xxxsmall: function xxxsmall(options) {
    return headlineFs("xxxsmall", Object.assign({}, headlineDefaults, options));
  },
  xxsmall: function xxsmall(options) {
    return headlineFs("xxsmall", Object.assign({}, headlineDefaults, options));
  },
  xsmall: function xsmall(options) {
    return headlineFs("xsmall", Object.assign({}, headlineDefaults, options));
  },
  small: function small(options) {
    return headlineFs("small", Object.assign({}, headlineDefaults, options));
  },
  medium: function medium(options) {
    return headlineFs("medium", Object.assign({}, headlineDefaults, options));
  },
  large: function large(options) {
    return headlineFs("large", Object.assign({}, headlineDefaults, options));
  },
  xlarge: function xlarge(options) {
    return headlineFs("xlarge", Object.assign({}, headlineDefaults, options));
  }
};
var bodyDefaults = {
  lineHeight: "loose",
  fontWeight: "regular",
  italic: false,
  unit: "rem"
};
var bodyFs = fs("body");
var body = {
  small: function small(options) {
    return bodyFs("small", Object.assign({}, bodyDefaults, options));
  },
  medium: function medium(options) {
    return bodyFs("medium", Object.assign({}, bodyDefaults, options));
  }
};
var textSansDefaults = {
  lineHeight: "loose",
  fontWeight: "regular",
  italic: false,
  unit: "rem"
};
var textSansFs = fs("textSans");
var textSans = {
  xsmall: function xsmall(options) {
    return textSansFs("xsmall", Object.assign({}, textSansDefaults, options));
  },
  small: function small(options) {
    return textSansFs("small", Object.assign({}, textSansDefaults, options));
  },
  medium: function medium(options) {
    return textSansFs("medium", Object.assign({}, textSansDefaults, options));
  },
  large: function large(options) {
    return textSansFs("large", Object.assign({}, textSansDefaults, options));
  },
  xlarge: function xlarge(options) {
    return textSansFs("xlarge", Object.assign({}, textSansDefaults, options));
  }
};

export { body, bodySizes, fontWeightMapping as fontWeights, fontMapping as fonts, headline, headlineSizes, lineHeightMapping as lineHeights, remBodySizes, remHeadlineSizes, remTextSansSizes, remTitlepieceSizes, textSans, textSansSizes, titlepiece, titlepieceSizes };

==> src-foundations-0.18.1.tgz: package/typography/obj/index.js <==
// The theme file is based on the specification at https://system-ui.com/theme
//
// WARNING!
//
// This is an internal file to be consumed by the src-foundations package only
//
// It contains the lowest level primitives for the entire design system.
// Be very, *very* careful when changing the values in here, changes are likely
// to have a wide-ranging impact across all applications
//
// DANGEROUS CHANGES
//
// The following will almost certainly require further changes to src-foundations.
// They will likely also impact every application that consumes src-foundations
//
// - Updating a value
// - Removing a value
// - Inserting a value into an array
//
// SAFE CHANGES
//
// - Pushing a value onto the end of an array
// - Exporting a new object or array
var fontSizes = [12, 15, 17, 20, 24, 28, 34, 42, 50, 70];
var fonts = {
  titlepiece: "GT Guardian Titlepiece, Georgia, serif",
  headlineSerif: "GH Guardian Headline, Guardian Egyptian Web, Georgia, serif",
  bodySerif: "GuardianTextEgyptian, Guardian Text Egyptian Web, Georgia, serif",
  bodySans: "GuardianTextSans, Guardian Text Sans Web, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif"
};
var lineHeights = [1.15, 1.35, 1.5];
var fontWeights = [300, 400, 500, 700]; // Arrays of colours should have pillar colors first

var titlepieceSizes = {
  small: fontSizes[7],
  //42px
  medium: fontSizes[8],
  //50px
  large: fontSizes[9] //70px

};
var headlineSizes = {
  xxxsmall: fontSizes[2],
  //17px
  xxsmall: fontSizes[3],
  //20px
  xsmall: fontSizes[4],
  //24px
  small: fontSizes[5],
  //28px
  medium: fontSizes[6],
  //34px
  large: fontSizes[7],
  //42px
  xlarge: fontSizes[8] //50px

};
var bodySizes = {
  small: fontSizes[1],
  //15px
  medium: fontSizes[2] //17px

};
var textSansSizes = {
  xsmall: fontSizes[0],
  //12px
  small: fontSizes[1],
  //15px
  medium: fontSizes[2],
  //17px
  large: fontSizes[3],
  //20px
  xlarge: fontSizes[4] //24px

};
var fontSizeMapping = {
  titlepiece: titlepieceSizes,
  headline: headlineSizes,
  body: bodySizes,
  textSans: textSansSizes
};
var remFontSizes = fontSizes.map(function (fontSize) {
  return fontSize / 16;
});
var remTitlepieceSizes = {
  small: remFontSizes[7],
  //42px
  medium: remFontSizes[8],
  //50px
  large: remFontSizes[9] //70px

};
var remHeadlineSizes = {
  xxxsmall: remFontSizes[2],
  //17px
  xxsmall: remFontSizes[3],
  //20px
  xsmall: remFontSizes[4],
  //24px
  small: remFontSizes[5],
  //28px
  medium: remFontSizes[6],
  //34px
  large: remFontSizes[7],
  //42px
  xlarge: remFontSizes[8] //50px

};
var remBodySizes = {
  small: remFontSizes[1],
  //15px
  medium: remFontSizes[2] //17px

};
var remTextSansSizes = {
  xsmall: remFontSizes[0],
  //12px
  small: remFontSizes[1],
  //15px
  medium: remFontSizes[2],
  //17px
  large: remFontSizes[3],
  //20px
  xlarge: remFontSizes[4] //24px

};
var fontMapping = {
  titlepiece: fonts.titlepiece,
  headline: fonts.headlineSerif,
  body: fonts.bodySerif,
  textSans: fonts.bodySans
};
var lineHeightMapping = {
  tight: lineHeights[0],
  regular: lineHeights[1],
  loose: lineHeights[2]
};
var fontWeightMapping = {
  light: fontWeights[0],
  regular: fontWeights[1],
  medium: fontWeights[2],
  bold: fontWeights[3]
};
var availableFonts = {
  titlepiece: {
    bold: {
      hasItalic: false
    }
  },
  headline: {
    light: {
      hasItalic: true
    },
    medium: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  },
  body: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: true
    }
  },
  textSans: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  }
};
Object.freeze(titlepieceSizes);
Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);
Object.freeze(remTitlepieceSizes);
Object.freeze(remHeadlineSizes);
Object.freeze(remBodySizes);
Object.freeze(remTextSansSizes);
Object.freeze(fontMapping);
Object.freeze(fontSizeMapping);
Object.freeze(fontWeightMapping);
Object.freeze(lineHeightMapping);
Object.freeze(availableFonts);

// Exists to support deprecated API, should be removed at some point
var legacyItalic = function legacyItalic(font, italic) {
  return italic && font !== undefined && font.hasItalic ? "italic" : null;
};

function getFontStyle(font, fontStyle, italic) {
  switch (fontStyle) {
    case "italic":
      return font && font.hasItalic ? "italic" : null;

    case "normal":
      return "normal";

    case null:
    default:
      return legacyItalic(font, italic);
  }
}

var fs = function fs(category) {
  return function (level, _ref) {
    var lineHeight = _ref.lineHeight,
        fontWeight = _ref.fontWeight,
        italic = _ref.italic,
        fontStyle = _ref.fontStyle,
        unit = _ref.unit;
    var fontFamilyValue = fontMapping[category];
    var fontSizeValue = unit === "px" ? fontSizeMapping[category][level] : "".concat(fontSizeMapping[category][level] / 16, "rem");
    var lineHeightValue = unit === "px" ? "".concat(lineHeightMapping[lineHeight] * fontSizeMapping[category][level], "px") : lineHeightMapping[lineHeight]; // TODO: consider logging an error in development if a requested
    // font is unavailable

    var requestedFont = availableFonts[category][fontWeight];
    var fontWeightValue = requestedFont ? fontWeightMapping[fontWeight] : "";
    var fontStyleValue = getFontStyle(requestedFont, fontStyle, italic);
    return Object.assign({
      fontFamily: fontFamilyValue,
      fontSize: fontSizeValue,
      lineHeight: lineHeightValue
    }, fontWeightValue ? {
      fontWeight: fontWeightValue
    } : {}, fontStyleValue ? {
      fontStyle: fontStyleValue
    } : {});
  };
};

var titlepieceDefaults = {
  lineHeight: "tight",
  fontWeight: "bold",
  italic: false,
  // Legacy property
  fontStyle: null,
  unit: "rem"
};
var titlepieceFs = fs("titlepiece");
var titlepiece = {
  small: function small(options) {
    return titlepieceFs("small", Object.assign({}, titlepieceDefaults, options));
  },
  medium: function medium(options) {
    return titlepieceFs("medium", Object.assign({}, titlepieceDefaults, options));
  },
  large: function large(options) {
    return titlepieceFs("large", Object.assign({}, titlepieceDefaults, options));
  }
};
var headlineDefaults = {
  lineHeight: "tight",
  fontWeight: "medium",
  italic: false,
  // Legacy property
  fontStyle: null,
  unit: "rem"
};
var headlineFs = fs("headline");
var headline = {
  xxxsmall: function xxxsmall(options) {
    return headlineFs("xxxsmall", Object.assign({}, headlineDefaults, options));
  },
  xxsmall: function xxsmall(options) {
    return headlineFs("xxsmall", Object.assign({}, headlineDefaults, options));
  },
  xsmall: function xsmall(options) {
    return headlineFs("xsmall", Object.assign({}, headlineDefaults, options));
  },
  small: function small(options) {
    return headlineFs("small", Object.assign({}, headlineDefaults, options));
  },
  medium: function medium(options) {
    return headlineFs("medium", Object.assign({}, headlineDefaults, options));
  },
  large: function large(options) {
    return headlineFs("large", Object.assign({}, headlineDefaults, options));
  },
  xlarge: function xlarge(options) {
    return headlineFs("xlarge", Object.assign({}, headlineDefaults, options));
  }
};
var bodyDefaults = {
  lineHeight: "loose",
  fontWeight: "regular",
  italic: false,
  // Legacy property
  fontStyle: null,
  unit: "rem"
};
var bodyFs = fs("body");
var body = {
  small: function small(options) {
    return bodyFs("small", Object.assign({}, bodyDefaults, options));
  },
  medium: function medium(options) {
    return bodyFs("medium", Object.assign({}, bodyDefaults, options));
  }
};
var textSansDefaults = {
  lineHeight: "loose",
  fontWeight: "regular",
  italic: false,
  // Legacy property
  fontStyle: null,
  unit: "rem"
};
var textSansFs = fs("textSans");
var textSans = {
  xsmall: function xsmall(options) {
    return textSansFs("xsmall", Object.assign({}, textSansDefaults, options));
  },
  small: function small(options) {
    return textSansFs("small", Object.assign({}, textSansDefaults, options));
  },
  medium: function medium(options) {
    return textSansFs("medium", Object.assign({}, textSansDefaults, options));
  },
  large: function large(options) {
    return textSansFs("large", Object.assign({}, textSansDefaults, options));
  },
  xlarge: function xlarge(options) {
    return textSansFs("xlarge", Object.assign({}, textSansDefaults, options));
  }
};

export { body, bodySizes, fontWeightMapping as fontWeights, fontMapping as fonts, headline, headlineSizes, lineHeightMapping as lineHeights, remBodySizes, remHeadlineSizes, remTextSansSizes, remTitlepieceSizes, textSans, textSansSizes, titlepiece, titlepieceSizes };
